Initial Development
-------------------

The first version of swidGenerator was developed during a bachelor's thesis at
HSR University of Applied Sciences Rapperswil (http://www.hsr.ch/) in spring 2014.

- Christian Fässler (@cfaessler)
- Danilo Bargen (@dbrgn)
- Jonas Furrer (@d22)

Other Contributions
-------------------

- ...
